@@ -2,6 +2,8 @@
 // SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "kalendaralarmclient.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "../src/calendarsettings.h"
 #include "alarmnotification.h"
 #include "calendarinterface.h"
@@ -61,7 +63,7 @@ void KalendarAlarmClient::setupAkonadi()
 {
     const QStringList mimeTypes{Event::eventMimeType(), Todo::todoMimeType()};
     mCalendar = Akonadi::ETMCalendar::Ptr(new Akonadi::ETMCalendar(mimeTypes));
-    mCalendar->setObjectName(QLatin1StringView("KalendarAC's calendar"));
+    mCalendar->setObjectName("KalendarAC's calendar"_L1);
     Akonadi::IncidenceChanger *changer = mCalendar->incidenceChanger();
     changer->setShowDialogsOnError(false);
     mETM = mCalendar->entityTreeModel();
@@ -104,7 +106,7 @@ void KalendarAlarmClient::deferredInit()
 void KalendarAlarmClient::restoreSuspendedFromConfig()
 {
     qCDebug(REMINDER_DAEMON_LOG) << "Restore suspended alarms from config";
-    const KConfigGroup suspendedGroup(KSharedConfig::openConfig(), QLatin1String(mySuspensedGroupName));
+    const KConfigGroup suspendedGroup(KSharedConfig::openConfig(), QLatin1StringView(mySuspensedGroupName));
     const auto suspendedAlarms = suspendedGroup.groupList();
 
     for (const auto &s : suspendedAlarms) {
@@ -171,8 +173,8 @@ void KalendarAlarmClient::showIncidence(const QString &uid, const QDateTime &occ
     job->setStartupId(xdgActivationToken.toUtf8());
     connect(job, &KJob::finished, this, [appId, kontactPlugin, uid, occurrence, xdgActivationToken]() {
         // if running inside Kontact, select the right plugin
-        if (appId == QLatin1String("org.kde.kontact")) {
-            const QString objectName = QLatin1Char('/') + kontactPlugin + QLatin1String("_PimApplication");
+        if (appId == "org.kde.kontact"_L1) {
+            const QString objectName = QLatin1Char('/') + kontactPlugin + "_PimApplication"_L1;
             QDBusInterface iface(appId, objectName, QStringLiteral("org.kde.PIMUniqueApplication"), QDBusConnection::sessionBus());
             if (iface.isValid()) {
                 QStringList arguments({kontactPlugin});
@@ -194,8 +196,8 @@ void KalendarAlarmClient::storeNotification(AlarmNotification *notification)
     const auto notificationUidUtf8 = notification->uid().toUtf8();
     const auto notificationUidData = notificationUidUtf8.constData();
 
-    KConfigGroup suspendedGroup(m_config, QLatin1String(mySuspensedGroupName));
-    KConfigGroup notificationGroup(&suspendedGroup, QLatin1String(notificationUidData));
+    KConfigGroup suspendedGroup(m_config, QLatin1StringView(mySuspensedGroupName));
+    KConfigGroup notificationGroup(&suspendedGroup, QLatin1StringView(notificationUidData));
     notificationGroup.writeEntry("UID", notificationUidData);
     notificationGroup.writeEntry("Text", notification->text());
     if (notification->occurrence().isValid()) {
@@ -213,8 +215,8 @@ void KalendarAlarmClient::removeNotification(AlarmNotification *notification)
     const auto notificationUidUtf8 = notification->uid().toUtf8();
     const auto notificationUidData = notificationUidUtf8.constData();
 
-    KConfigGroup suspendedGroup(m_config, QLatin1String(mySuspensedGroupName));
-    KConfigGroup notificationGroup(&suspendedGroup, QLatin1String(notificationUidData));
+    KConfigGroup suspendedGroup(m_config, QLatin1StringView(mySuspensedGroupName));
+    KConfigGroup notificationGroup(&suspendedGroup, QLatin1StringView(notificationUidData));
     notificationGroup.deleteGroup();
     KSharedConfig::openConfig()->sync();
 }
